@@ -86,9 +86,41 @@ def log(message: str) -> None:
     print(message, flush=True)
 
 
+def command_exists(
+    command: str, silent: bool = False, exit_on_error: bool = False
+) -> bool:
+    """Checks whether the `command` exists and is marked as executable.
+
+    Args:
+        command (str): Command to check.
+        silent (bool): If `True`, no message will be logged in case the command does not exist. Default is `False`.
+        exit_on_error (bool, optional): Exit process if the command does not exist. Defaults to `False`.
+
+    Returns:
+        bool: `True` if the commend exist and is executable.
+    """
+
+    # Alternative:
+    # import distutils.spawn
+    # return distutils.spawn.find_executable(name)
+
+    from shutil import which
+
+    exists: bool = which(command) is not None
+
+    if not exists and not silent:
+        log(
+            f"The command {command} does not exist on the system or is not executable. Make sure to install {command}."
+        )
+        if exit_on_error:
+            exit_process(1)
+
+    return exists
+
+
 def parse_arguments(
     input_args: List[str] = None, argument_parser: argparse.ArgumentParser = None
-) -> Dict[str, Union[str, bool, List[str]]]:
+) -> dict:
     """Parses all arguments and returns a sanitized & augmented list of arguments.
 
     Sanitized means that, for example, the version is already checked and set depending on our build guidelines.
@@ -99,7 +131,7 @@ def parse_arguments(
         argument_parser (arparse.ArgumentParser, optional): An argument parser which is passed as a parents parser to the default ArgumentParser to be able to use additional flags besides the default ones.
 
     Returns:
-        Dict[str, Union[str, bool, List[str]]]: The parsed default arguments thar are already checked for validity.
+        dict: The parsed default arguments thar are already checked for validity.
     """
     argument_parser = argument_parser or argparse.ArgumentParser()
     parser = _get_default_cli_arguments_parser(argument_parser)
@@ -230,6 +262,7 @@ def create_git_tag(
         version (str): The tag to be created. Will be prefixed with 'v'.
         push (bool, optional): If true, push the tag to remote. Defaults to False.
         force (bool, optional): If true, force the tag to be created. Defaults to False.
+        exit_on_error (bool): Exit program if the tag creation fails.
 
     Returns:
         subprocess.CompletedProcess: Returns the CompletedProcess object of either the `git tag` or the `git push tag` command. If `push` is set to true, the CompletedProcess of `git tag` is returned if it failed, otherwise the CompletedProcess object from the `git push tag` command is returned.
@@ -350,6 +383,57 @@ def exit_process(code: int = 0) -> None:
     os._exit(code)
 
 
+def replace_in_files(
+    find: str,
+    replace: str,
+    file_paths: List[str],
+    regex: bool = False,
+    exit_on_error: bool = True,
+) -> None:
+    """Replaces a string or regex occurence in a collection of files.
+
+    Args:
+        find (str): A string to find and replace in the files.
+        replace (str): The string to replace it with.
+        file_paths (List[str]): Collection of file paths.
+        regex (bool, optional): If `True`, apply the find string as a regex notation. Defaults to `False`.
+        exit_on_error (bool, optional): If `True`, exit process as soon as error occures. Defaults to True.
+    """
+    for file_path in file_paths:
+        if not os.path.exists(file_path):
+            log("File path does not exist for string replacement: " + file_path)
+            if exit_on_error:
+                exit_process(1)
+        try:
+            with open(file_path, "r+") as f:
+                data = f.read()
+                f.seek(0)
+                if regex:
+                    f.write(re.sub(find, replace, data))
+                else:
+                    f.write(data.replace(find, replace))
+                f.truncate()
+        except Exception as ex:
+            log(
+                "Failed to replace string in file: "
+                + file_path
+                + ". Exception: "
+                + str(ex)
+            )
+            if exit_on_error:
+                exit_process(1)
+
+
+def get_latest_version() -> Optional[str]:
+    """Returns the latest version based on Git tags."""
+    try:
+        latest_version = _get_latest_branch_version()
+        assert latest_version is not None
+        return latest_version.to_string()
+    except Exception:
+        return None
+
+
 def duplicate_folder(
     src_path: str, target_path: str, exit_on_error: bool = True
 ) -> None:
